@@ -33,10 +33,7 @@ except ImportError:
 
 from .conf import config, cookiejar
 
-try:
-    from .meter import TextMeter
-except:
-    TextMeter = None
+from .meter import create_text_meter
 
 change_personality = {
             'i686':  'linux32',
@@ -256,18 +253,8 @@ class Pac:
     def makeurls(self, cachedir, urllist):
 
         self.urllist = []
-
-        # build up local URL
-        # by using the urlgrabber with local urls, we basically build up a cache.
-        # the cache has no validation, since the package servers don't support etags,
-        # or if-modified-since, so the caching is simply name-based (on the assumption
-        # that the filename is suitable as identifier)
         self.localdir = '%s/%s/%s/%s' % (cachedir, self.project, self.repository, self.arch)
         self.fullfilename = os.path.join(self.localdir, self.canonname)
-        self.url_local = 'file://%s' % self.fullfilename
-
-        # first, add the local URL
-        self.urllist.append(self.url_local)
 
         # remote URLs
         for url in urllist:
@@ -318,15 +305,14 @@ def get_preinstall_image(apiurl, arch, cache_dir, img_info):
                 print('packagecachedir is not writable for you?', file=sys.stderr)
                 print(e, file=sys.stderr)
                 sys.exit(1)
-        if sys.stdout.isatty() and TextMeter:
-            progress_obj = TextMeter(fo=sys.stdout)
-        else:
-            progress_obj = None
+        progress_obj = None
+        if sys.stdout.isatty():
+            progress_obj = create_text_meter(use_pb_fallback=False)
         gr = OscFileGrabber(progress_obj=progress_obj)
         try:
             gr.urlgrab(url, filename=ifile_path_part, text='fetching image')
-        except URLGrabError as e:
-            print("Failed to download! ecode:%i errno:%i" % (e.code, e.errno))
+        except HTTPError as e:
+            print("Failed to download! ecode:%i reason:%i" % (e.code, e.reason))
             return ('', '', [])
         # download ok, rename partial file to final file name
         os.rename(ifile_path_part, ifile_path)
@@ -350,6 +336,11 @@ def get_built_files(pacdir, buildtype):
                                     '-type', 'f'],
                                    stdout=subprocess.PIPE).stdout.read().strip()
         s_built = ''
+    elif buildtype == 'podman':
+        b_built = subprocess.Popen(['find', os.path.join(pacdir, 'DOCKER'),
+                                    '-type', 'f'],
+                                   stdout=subprocess.PIPE).stdout.read().strip()
+        s_built = ''
     elif buildtype == 'fissile':
         b_built = subprocess.Popen(['find', os.path.join(pacdir, 'FISSILE'),
                                     '-type', 'f'],
@@ -473,6 +464,12 @@ def create_deps(pkgqs):
         d = p.obsoletes()
         if d:
             depfile.append('O:%s%s' % (id, ' '.join(d)))
+        d = p.recommends()
+        if d:
+            depfile.append('r:%s%s' % (id, ' '.join(d)))
+        d = p.supplements()
+        if d:
+            depfile.append('s:%s%s' % (id, ' '.join(d)))
         depfile.append('I:%s%s-%s 0-%s' % (id, p.name(), p.evr(), p.arch()))
     return depfile
 
@@ -528,7 +525,7 @@ def main(apiurl, opts, argv):
         build_type = 'docker'
     if os.path.basename(build_descr) == 'fissile.yml':
         build_type = 'fissile'
-    if build_type not in ['spec', 'dsc', 'kiwi', 'arch', 'collax', 'livebuild', 'snapcraft', 'appimage', 'docker', 'fissile']:
+    if build_type not in ['spec', 'dsc', 'kiwi', 'arch', 'collax', 'livebuild', 'snapcraft', 'appimage', 'docker', 'podman', 'fissile']:
         raise oscerr.WrongArgs(
                 'Unknown build type: \'%s\'. Build description should end in .spec, .dsc, .kiwi, or .livebuild. Or being named PKGBUILD, build.collax, appimage.yml, snapcraft.yaml or Dockerfile' \
                         % build_type)
@@ -536,6 +533,7 @@ def main(apiurl, opts, argv):
         raise oscerr.WrongArgs('Error: build description file named \'%s\' does not exist.' % build_descr)
 
     buildargs = []
+    buildargs.append('--statistics')
     if not opts.userootforbuild:
         buildargs.append('--norootforbuild')
     if opts.clean:
@@ -589,7 +587,7 @@ def main(apiurl, opts, argv):
     if opts.build_uid:
         build_uid = opts.build_uid
     if build_uid:
-        buildidre = re.compile('^[0-9]{1,5}:[0-9]{1,5}$')
+        buildidre = re.compile('^[0-9]+:[0-9]+$')
         if build_uid == 'caller':
             buildargs.append('--uid=%s:%s' % (os.getuid(), os.getgid()))
         elif buildidre.match(build_uid):
@@ -614,7 +612,8 @@ def main(apiurl, opts, argv):
             pac = store_read_package(os.curdir)
     if opts.multibuild_package:
         buildargs.append('--buildflavor=%s' % opts.multibuild_package)
-        pac = pac + ":" + opts.multibuild_package
+        if pac != '_repository':
+            pac = pac + ":" + opts.multibuild_package
     if opts.shell:
         buildargs.append("--shell")
 
@@ -978,7 +977,7 @@ def main(apiurl, opts, argv):
             buildargs.append('--oldpackages=%s' % old_pkg_dir)
 
     # Make packages from buildinfo available as repos for kiwi/docker/fissile
-    if build_type == 'kiwi' or build_type == 'docker' or build_type == 'fissile':
+    if build_type == 'kiwi' or build_type == 'docker' or build_type == 'podman' or build_type == 'fissile':
         if os.path.exists('repos'):
             shutil.rmtree('repos')
         if os.path.exists('containers'):
@@ -1121,7 +1120,7 @@ def main(apiurl, opts, argv):
 
     print('Writing build configuration')
 
-    if build_type == 'kiwi' or build_type == 'docker' or build_type == 'fissile':
+    if build_type == 'kiwi' or build_type == 'docker' or build_type == 'podman'or build_type == 'fissile':
         rpmlist = [ '%s %s\n' % (i.name, i.fullfilename) for i in bi.deps if not i.noinstall ]
     else:
         rpmlist = [ '%s %s\n' % (i.name, i.fullfilename) for i in bi.deps ]
@@ -1137,7 +1136,7 @@ def main(apiurl, opts, argv):
     rpmlist.append('preinstall: ' + ' '.join(bi.preinstall_list) + '\n')
     rpmlist.append('vminstall: ' + ' '.join(bi.vminstall_list) + '\n')
     rpmlist.append('runscripts: ' + ' '.join(bi.runscripts_list) + '\n')
-    if build_type != 'kiwi' and build_type != 'docker' and build_type != 'fissile':
+    if build_type != 'kiwi' and build_type != 'docker' and build_type != 'podman' and build_type != 'fissile':
         if bi.noinstall_list:
             rpmlist.append('noinstall: ' + ' '.join(bi.noinstall_list) + '\n')
         if bi.installonly_list:
