@@ -118,7 +118,7 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             'build-kernel': '',                 # optional for VM builds
             'build-initrd': '',                 # optional for VM builds
 
-            'build-jobs': _get_processors(),
+            'build-jobs': str(_get_processors()),
             'builtin_signature_check': '1',     # by default use builtin check for verify pkgs
             'icecream': '0',
 
@@ -201,8 +201,9 @@ boolean_opts = ['debug', 'do_package_tracking', 'http_debug', 'post_mortem', 'tr
     'request_show_source_buildstatus', 'review_inherit_group', 'use_keyring', 'gnome_keyring', 'no_verify', 'builtin_signature_check',
     'http_full_debug', 'include_request_from_project', 'local_service_run', 'buildlog_strip_time', 'no_preinstallimage',
     'status_mtime_heuristic']
+integer_opts = ['build-jobs']
 
-api_host_options = ['user', 'pass', 'passx', 'aliases', 'http_headers', 'email', 'sslcertck', 'cafile', 'capath', 'trusted_prj']
+api_host_options = ['user', 'pass', 'passx', 'aliases', 'http_headers', 'realname', 'email', 'sslcertck', 'cafile', 'capath', 'trusted_prj']
 
 new_conf_template = """
 [general]
@@ -361,6 +362,8 @@ user = %(user)s
 pass = %(pass)s
 # set aliases for this apiurl
 # aliases = foo, bar
+# real name used in .changes, unless the one from osc meta prj <user> will be used
+# realname =
 # email used in .changes, unless the one from osc meta prj <user> will be used
 # email =
 # additional headers to pass to a request, e.g. for special authentication
@@ -546,10 +549,10 @@ def _build_opener(apiurl):
                     capath = i
                     break
         if not cafile and not capath:
-            raise oscerr.OscIOError(None, 'No CA certificates found')
+            raise oscerr.OscIOError(None, 'No CA certificates found. (You may want to install ca-certificates-mozilla package)')
         ctx = oscssl.mySSLContext()
         if ctx.load_verify_locations(capath=capath, cafile=cafile) != 1:
-            raise oscerr.OscIOError(None, 'No CA certificates found')
+            raise oscerr.OscIOError(None, 'No CA certificates found. (You may want to install ca-certificates-mozilla package)')
         opener = m2urllib2.build_opener(ctx, oscssl.myHTTPSHandler(ssl_context=ctx, appname='osc'), HTTPCookieProcessor(cookiejar), authhandler, proxyhandler)
     else:
         handlers = [HTTPCookieProcessor(cookiejar), authhandler, proxyhandler]
@@ -848,11 +851,14 @@ def get_config(override_conffile=None,
     config = dict(cp.items('general', raw=1))
     config['conffile'] = conffile
 
-    for i in boolean_opts:
-        try:
-            config[i] = cp.getboolean('general', i)
-        except ValueError as e:
-            raise oscerr.ConfigError('cannot parse \'%s\' setting: ' % i + str(e), conffile)
+    typed_opts = ((boolean_opts, cp.getboolean), (integer_opts, cp.getint))
+    for opts, meth in typed_opts:
+        for opt in opts:
+            try:
+                config[opt] = meth('general', opt)
+            except ValueError as e:
+                msg = 'cannot parse \'%s\' setting: %s' % (opt, str(e))
+                raise oscerr.ConfigError(msg, conffile)
 
     config['packagecachedir'] = os.path.expanduser(config['packagecachedir'])
     config['exclude_glob'] = config['exclude_glob'].split()
@@ -970,7 +976,7 @@ def get_config(override_conffile=None,
                                     'pass': password,
                                     'http_headers': http_headers}
 
-        optional = ('email', 'sslcertck', 'cafile', 'capath')
+        optional = ('realname', 'email', 'sslcertck', 'cafile', 'capath')
         for key in optional:
             if cp.has_option(url, key):
                 if key == 'sslcertck':
