@@ -60,18 +60,18 @@ class PackageQuery:
         f.seek(0)
         extra_tags = ()
         pkgquery = None
-        if magic[:4] == '\xed\xab\xee\xdb':
+        if magic[:4] == b'\xed\xab\xee\xdb':
             from . import rpmquery
             pkgquery = rpmquery.RpmQuery(f)
             extra_tags = extra_rpmtags
-        elif magic == '!<arch>':
+        elif magic == b'!<arch>':
             from . import debquery
             pkgquery = debquery.DebQuery(f)
             extra_tags = extra_debtags
-        elif magic[:5] == '<?xml':
+        elif magic[:5] == b'<?xml':
             f.close()
             return None
-        elif magic[:5] == '\375\067zXZ' or magic[:2] == '\037\213':
+        elif magic[:5] == b'\375\067zXZ' or magic[:2] == b'\037\213':
             from . import archquery
             pkgquery = archquery.ArchQuery(f)
         else:
@@ -127,6 +127,18 @@ class PackageQueryResult:
     def obsoletes(self):
         raise NotImplementedError
 
+    def recommends(self):
+        raise NotImplementedError
+
+    def suggests(self):
+        raise NotImplementedError
+
+    def supplements(self):
+        raise NotImplementedError
+
+    def enhances(self):
+        raise NotImplementedError
+
     def gettag(self, tag):
         raise NotImplementedError
 
@@ -147,6 +159,11 @@ class PackageQueryResult:
             evr = epoch + ":" + evr 
         return evr 
 
+
+def cmp(a, b):
+    return (a > b) - (a < b)
+
+
 if __name__ == '__main__':
     import sys
     try:
