@@ -23,6 +23,7 @@ import test_request
 import test_setlinkrev
 import test_prdiff
 import test_conf
+import test_results
 
 suite = unittest.TestSuite()
 suite.addTests(test_addfiles.suite())
@@ -40,6 +41,7 @@ suite.addTests(test_request.suite())
 suite.addTests(test_setlinkrev.suite())
 suite.addTests(test_prdiff.suite())
 suite.addTests(test_conf.suite())
+suite.addTests(test_results.suite())
 
 if have_xmlrunner:
     result = xmlrunner.XMLTestRunner(output=os.path.join(os.getcwd(), 'junit-xml-results')).run(suite)
